@@ -218,19 +218,17 @@ static int elan_query_product(struct elan_tp_data *data)
 
 static int elan_check_ASUS_special_fw(struct elan_tp_data *data)
 {
-	if (data->ic_type == 0x0E) {
-		switch (data->product_id) {
-		case 0x05 ... 0x07:
-		case 0x09:
-		case 0x13:
-			return true;
-		}
-	} else if (data->ic_type == 0x08 && data->product_id == 0x26) {
-		/* ASUS EeeBook X205TA */
-		return true;
-	}
+	if (data->ic_type != 0x0E)
+		return false;
 
-	return false;
+	switch (data->product_id) {
+	case 0x05 ... 0x07:
+	case 0x09:
+	case 0x13:
+		return true;
+	default:
+		return false;
+	}
 }
 
 static int __elan_initialize(struct elan_tp_data *data)
@@ -1082,13 +1080,6 @@ static int elan_probe(struct i2c_client *client,
 		return error;
 	}
 
-	/* Make sure there is something at this address */
-	error = i2c_smbus_read_byte(client);
-	if (error < 0) {
-		dev_dbg(&client->dev, "nothing at this address: %d\n", error);
-		return -ENXIO;
-	}
-
 	/* Initialize the touchpad. */
 	error = elan_initialize(data);
 	if (error)
@@ -1241,14 +1232,7 @@ static const struct acpi_device_id elan_acpi_id[] = {
 	{ "ELAN0000", 0 },
 	{ "ELAN0100", 0 },
 	{ "ELAN0600", 0 },
-	{ "ELAN0602", 0 },
 	{ "ELAN0605", 0 },
-	{ "ELAN0608", 0 },
-	{ "ELAN0605", 0 },
-	{ "ELAN0609", 0 },
-	{ "ELAN060B", 0 },
-	{ "ELAN060C", 0 },
-	{ "ELAN0611", 0 },
 	{ "ELAN1000", 0 },
 	{ }
 };
